"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const clone = require("clone");
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const qs_1 = require("qs");
const url_1 = require("url");
const browser_1 = require("../browser");
const server_1 = require("../server");
class FacadePuppeteer {
    constructor() { }
    static create() {
        return new FacadePuppeteer();
    }
    ;
    async createPage(url, requirePuppeteerCb, waitForOptions, rendererOptions = {}, browserUrl) {
        const { pageUrl, server } = await this.hostContent(url);
        const puppeteer = await requirePuppeteerCb();
        const { browser, closeBrowser } = await browser_1.createBrowser(puppeteer, rendererOptions, browserUrl);
        this.browser = browser;
        this.closeBrowser = async () => {
            await closeBrowser();
            server && server.stop();
        };
        this.page = await this.browser.newPage();
        await this.exposeClone();
        await this.page.goto(pageUrl, waitForOptions);
    }
    async hostContent(url) {
        const { href, protocol } = new URL(url);
        if (protocol === 'file:') {
            const rootPath = path_1.dirname(url_1.fileURLToPath(href));
            const server = await server_1.createServer(rootPath);
            const pageUrl = `http://localhost:${server.port}`;
            return { pageUrl, server };
        }
        return { pageUrl: url, server: undefined };
    }
    async exposeClone() {
        try {
            await this.page.exposeFunction('clone', clone);
        }
        catch (e) {
            console.log('\'Clone\' function already exposed!');
        }
    }
    async addScriptsToPage(scripts) {
        for (const script of scripts) {
            await this.page.addScriptTag({ path: script });
        }
    }
    async screenshot(opts) {
        await this.page.screenshot(opts);
    }
    async createRequestInterceptor(opts, requestedFile) {
        this.page.removeAllListeners('request');
        await this.page.setRequestInterception(true);
        this.page.on('request', (request) => {
            if (request.url().includes(requestedFile)) {
                const { theme, clm } = opts;
                const queryString = qs_1.stringify({ theme, clm }, { addQueryPrefix: true });
                request.continue({ url: `${request.url()}${queryString}` });
                return;
            }
            request.continue();
        });
        await this.page.reload();
    }
    async renderBlocks(contentPath, blocks = []) {
        const renderOneBlock = blocks.length === 1;
        const editorJS = path_1.join(contentPath, 'build/dev/editor.js');
        const renderBlocksJS = path_1.join(__dirname, '../../injected-scripts/renderBlocks.js');
        const injectedScriptsArray = [renderBlocksJS];
        const packageJSON = await fs_extra_1.readJSON(path_1.join(contentPath, 'package.json'));
        if (packageJSON.dependencies.ewizardjs) {
            injectedScriptsArray.push(editorJS);
        }
        await this.addScriptsToPage(injectedScriptsArray);
        await this.page.evaluate(({ renderOneBlock, blocks }) => {
            if (renderOneBlock) {
                const block = window.__blocks.find(({ name }) => blocks.includes(name));
                window.__renderBlock(block);
            }
            else {
                const currentThemeBlocks = window.__blocks.filter(({ name }) => blocks.includes(name));
                const blocksForRender = currentThemeBlocks.length ? currentThemeBlocks : window.__blocks;
                window.__renderBlocks(blocksForRender);
            }
        }, { renderOneBlock, blocks });
    }
    async getWindowData(windowProps) {
        const propsObj = {};
        const context = { propsObj, windowProps };
        const windowData = await this.page.evaluate(async (context) => {
            for (const prop of context.windowProps) {
                const clonedObject = await clone(window[prop]);
                context.propsObj[prop] = clonedObject;
            }
            return context.propsObj;
        }, context);
        return windowData;
    }
    async getElement(selector) {
        return this.page.$(selector);
    }
}
exports.default = FacadePuppeteer;
//# sourceMappingURL=index.js.map