"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createBrowser = void 0;
const getPuppeteerArgs_1 = require("../../configs/getPuppeteerArgs");
const defaultViewport = {
    width: 1024,
    height: 768,
};
function getBrowserInstance(puppeteer, rendererOptions = {}, browserURL) {
    if (browserURL) {
        return puppeteer.connect({
            browserURL,
            defaultViewport,
        });
    }
    return puppeteer.launch(Object.assign({ defaultViewport, args: getPuppeteerArgs_1.getPuppeteerArgs() }, rendererOptions));
}
async function createBrowser(puppeteer, rendererOptions = {}, browserURL) {
    const browser = await getBrowserInstance(puppeteer, rendererOptions, browserURL);
    const context = await browser.createIncognitoBrowserContext();
    const currentContext = browserURL ? context : browser;
    return {
        browser: currentContext,
        closeBrowser: async () => {
            if (browserURL) {
                await context.close();
                await browser.disconnect();
            }
            else {
                await browser.close();
            }
        },
    };
}
exports.createBrowser = createBrowser;
//# sourceMappingURL=index.js.map